@@ -324,6 +324,7 @@ main (int argc, char *argv[])
   gboolean a_t_support;
   GError *err;
   int status;
+  char *display_str;
   
   if (getenv ("GSM_VERBOSE_DEBUG"))
     gsm_set_verbose (TRUE);
@@ -345,13 +346,6 @@ main (int argc, char *argv[])
   /* We need to do this as early as possible */
   gsm_set_display_properties ();
   
-  /* Make sure the splash screen has the SM_CLIENT_ID
-   * property set so smproxy doesn't try and session
-   * manage us.
-   * See http://bugzilla.gnome.org/show_bug.cgi?id=118063
-   */
-  gdk_set_sm_client_id ("gnome-session-dummy-id");
-
   gnome_login_check ();
 
   err = NULL;
@@ -392,7 +386,9 @@ main (int argc, char *argv[])
 
   /* Make sure children see the right value for DISPLAY.  This is
      useful if --display was specified on the command line.  */
-  ep = g_strconcat ("DISPLAY=", gdk_get_display (), NULL);
+  display_str = gdk_get_display ();
+  ep = g_strconcat ("DISPLAY=", display_str, NULL);
+  g_free (display_str);
   putenv (ep);
 
   ignore (SIGPIPE);
